// Class used if the GTN650 instrument is not installed in the community directory
class GTN650_NOGTN650 extends BaseInstrument {
    get templateID() { return "GTN650_INT"; }  // ID if the instrument in HTML
    get instrumentAlias() { return "GTN650"; }
    constructor() {
        super();
    }
    connectedCallback() {
        super.connectedCallback();
    }
}


// Check if the GTN650 instrument is installed 
// We try to read a file of the package in the Virtual file system
let httpRequest = new XMLHttpRequest();
httpRequest.onreadystatechange = function (data) {
    if (this.readyState === XMLHttpRequest.DONE) {
        let loaded = this.status === 200 || this.status === 0;
        if (loaded) {
            // GTN650 is installed
            // Register the instrument
            Include.addScript("/Pms50/gtn750/Pages/VCockpit/Instruments/NavSystems/GPS/GTN750/js/GTN750.js", function () {
                registerInstrument("gtn650-int-element", GTN650_INT);
                // Set a global variable telling we are installed
                SimVar.SetSimVarValue("L:PMS50_GTN650_INSTALLED", "bool", true);
            });
        }
        else {
            // GTN650 is NOT installed
            // Set a global variable telling we are not installed
            SimVar.SetSimVarValue("L:PMS50_GTN650_INSTALLED", "bool", false);
            // Register the fake instrument
            registerInstrument("gtn650-int-element", GTN650_NOGTN650);
        }
    }
};
var milliseconds = new Date().getTime().toString();
httpRequest.open("GET", "/VFS/Integration/gtn750_interface/check.txt?id=" + milliseconds);
httpRequest.send();
